abacusai.batch_prediction_version_logs — AbacusAI documentation

# abacusai.batch_prediction_version_logs

## Classes

`BatchPredictionVersionLogs` | Logs from batch prediction version.

## Module Contents

class abacusai.batch_prediction_version_logs.BatchPredictionVersionLogs(client, logs=None, warnings=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Logs from batch prediction version.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - logs (list[str]) – List of logs from batch prediction version.

    - warnings (list[str]) – List of warnings from batch prediction version.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict